@@ -416,6 +416,9 @@ static int csptoc(apr_pool_t *p, GROWMEM * ten,char * dstcfile,char * dstdir,GRO
     }else
      if(*(buffer+i)=='"'){
       gm_puts(t1,"\\\"");
+     } else
+     if(*(buffer+i)=='\\'){
+      gm_puts(t1,"\\\\");
      } else
       gm_putc(t1,* (buffer+i));
     i++;
@@ -895,7 +898,7 @@ static int csptoc(apr_pool_t *p, GROWMEM * ten,char * dstcfile,char * dstdir,GRO
 "	return 0;\n"
 "}\n"
 "\n"
-# 189 "trans.c" 2
+# 192 "trans.c" 2
  ,fpw);
 
  char * t11 = gm_getmem(t1);
@@ -1028,6 +1031,7 @@ static void sessionSet(int * session_index,struct _sessionTable * session,char *
 # 14 "include.c" 2
 
 
+
 ////////////////////////////////////////////////////////////////////////////////////////////////
 //		debug
 ////////////////////////////////////////////////////////////////////////////////////////////////
